Glossary
========

Here we provide a glossary for some of the frequently used terms in this documentation. Feel free to come back to this page when you come across a term that you don't understand!

.. glossary::

    Anaconda
        Anaconda is an open-source distribution of the Python and R programming languages. It is used for scientific computing. Anaconda comes with over 250 packages automatically installed, and allows for over 7,500 additional open-source packages to be installed via PyPI, the conda package and virrtual environment manager.

    Anaconda Prompt
        Anaconda prompt is a command line shell. This is much like terminal for mac or cmd for windows. However, Anaconda Prompt allows you to run anaconda and conda commands from the prompt, without the need to change directories or your path.

    Benchmark years
        These are the years which the model solves and presents outputs for. This can be set by the user and represents the evolution of the system in each time step. This, for example, can be set for every year or every five years, depending on the granularity required by the user.

    Energy system
        An energy system is a system which is primarily designed to supply energy services to end-users. This can be defined as all components related to the production, conversion, delivery, and use of energy.

    End-use demand
        The end-use demand is the demand for energy required to produce an energy service. For example, the gas required by a gas boiler to produce hot water, for the energy service of space heating.

    Energy service
        The energy service is the service which a technology is used for. An example of an energy service could be cooking from a cooker.

    End-use technology
        An end-use technology is a technology which service an energy service.  Examples of these include boiler, heaters and stoves which service hot water, heating and cooking.

    Endogenous quantity
        An endogenous quantity is one which develops within the model, as opposed to an exogenous quantity which is specified by the user and not influenced by the model.

    Equilibrium
        An equilibrium is a situation in which economic forces, such as supply and demand are balanced. This means that, in the absence of external forces, the value of economic variables will not change.

    Exogenous quantity
        An exogenous quantity is a quantity which is set by the user, and does not change based upon the simulation.

    Imperfect information
        This is where an agent does not know everything needed to make a perfect decision.

    Levelised cost of electricity
        The levelised cost of electricity is a measure of the average net present cost of electricity generation for a generating plant over its lifetime.

    Limited foresight
        Limited foresight is the condition that an agent is unable to predict the entire future perfectly. The agent is only able to predict the future either imperfectly, or a limited time ahead.

    Open-source
        Open-source is a source code that is made freely available for users to modify and redistribute.

    Pandas
        Pandas is a data manipulation library for python.

    Petajoules (PJ)
        A petajoule is equal to 1.0E+15 joules. A joule is a unit of energy and is equal to the energy transferred to an object.

    Seaborn
        Seaborn is a visualisation library in python.

    Scenario analysis
        Scenario analysis is a process of analysing the future by considering different possibilities of a future. Through this analysis multiple alternative future developments are presented, as opposed to a single prediction.

    Simulation
        A simulation is computer software which models, or imitates a process or system. They can be used to observe what the effect of changes are over time to the system in question.

    Timeslice
        A timeslice is the way in which a benchmark year is split into various different sections. For example, a benchmark year could be split into four seasons, or as far as for each hour within a benchmark year.
